@@ -8,6 +8,8 @@ import abc
 from django.conf import settings
 from six import with_metaclass
 
+# нужно для импорта констант отсюда в barsdoc
+from m3_gar_constants import *
 from m3_gar_client.utils import cached_property
 
 
