@@ -23,7 +23,7 @@ from six.moves import (
 from m3_gar_client.backends.m3_rest_gar.proxy.server import (
     server,
 )
-from m3_gar_client.constants import (
+from m3_gar_constants import (
     DEFAULT_PAGE_LIMIT,
     GAR_HIERARCHY_MUN,
     GAR_LEVELS_PLACE,
@@ -152,6 +152,8 @@ class UIHouseMapper(ObjectMapper):
         'structureNumber': 'addnum2',
         'postalCode': 'params__PostIndex__value',
         'houseType': 'housetype__shortname',
+        'buildingType': 'addtype1__shortname',
+        'structureType': 'addtype2__shortname',
     }
 
 
@@ -501,6 +503,14 @@ class StreetLoader(AddressObjectLoaderBase):
 
     _mapper_class = UIAddressObjectMapper
 
+    @property
+    def _filter_param(self):
+        """Query-параметр для фильтрации.
+
+        :rtype: str
+        """
+        return 'name_with_typename'
+
 
 class HouseLoader(ParentFilterMixin, LoaderBase):
     """
