@@ -18,7 +18,7 @@ from six import iterkeys
 from six import text_type
 from six import with_metaclass
 
-from m3_gar_client.constants import GAR_LEVELS
+from m3_gar_constants import GAR_LEVELS
 
 
 FieldDescriptor = namedtuple('FieldDescriptor', [
